==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebGridActionsBaseDirectiveDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridActionsBaseDirectiveDescription } from "./WebGridActionsBaseDirectiveDescription";
/**
 * @hidden
 */
export let WebGridActionsBaseDirectiveDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridActionsBaseDirectiveDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridActionsBaseDirectiveDescriptionMetadata.a == null) {
                WebGridActionsBaseDirectiveDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridActionsBaseDirectiveDescriptionMetadata.c(WebGridActionsBaseDirectiveDescriptionMetadata.a);
            }
            if (a.k(WebGridActionsBaseDirectiveDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebGridActionsBaseDirectiveDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridActionsBaseDirective");
            a.item("__tagNameWC", "String:igc-grid-action-base-directive");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__skipSuffix", "Boolean");
            a.item("__manageCollectionInMarkup", "Boolean");
            a.item("AsMenuItems", "Boolean");
            a.item("Name", "String");
        }
        static d(a) {
            WebGridActionsBaseDirectiveDescriptionMetadata.b(a);
            a.ad("WebGridActionsBaseDirective", () => new WebGridActionsBaseDirectiveDescription());
            a.ac("WebGridActionsBaseDirective", WebGridActionsBaseDirectiveDescriptionMetadata.a);
        }
    }
    WebGridActionsBaseDirectiveDescriptionMetadata.$t = markType(WebGridActionsBaseDirectiveDescriptionMetadata, 'WebGridActionsBaseDirectiveDescriptionMetadata');
    WebGridActionsBaseDirectiveDescriptionMetadata.a = null;
    return WebGridActionsBaseDirectiveDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebGridActionsBaseDirectiveDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridActionsBaseDirectiveDescription } from "./WebGridActionsBaseDirectiveDescription";
/**
 * @hidden
 */
export let WebGridActionsBaseDirectiveDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridActionsBaseDirectiveDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridActionsBaseDirectiveDescriptionMetadata.a == null) {
                WebGridActionsBaseDirectiveDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridActionsBaseDirectiveDescriptionMetadata.c(WebGridActionsBaseDirectiveDescriptionMetadata.a);
            }
            if (a.k(WebGridActionsBaseDirectiveDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebGridActionsBaseDirectiveDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridActionsBaseDirective");
            a.item("__tagNameWC", "String:igc-grid-action-base-directive");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__skipSuffix", "Boolean");
            a.item("__manageCollectionInMarkup", "Boolean");
            a.item("AsMenuItems", "Boolean");
            a.item("Name", "String");
        }
        static d(a) {
            WebGridActionsBaseDirectiveDescriptionMetadata.b(a);
            a.ae("WebGridActionsBaseDirective", () => new WebGridActionsBaseDirectiveDescription());
            a.ad("WebGridActionsBaseDirective", WebGridActionsBaseDirectiveDescriptionMetadata.a);
        }
    }
    WebGridActionsBaseDirectiveDescriptionMetadata.$t = markType(WebGridActionsBaseDirectiveDescriptionMetadata, 'WebGridActionsBaseDirectiveDescriptionMetadata');
    WebGridActionsBaseDirectiveDescriptionMetadata.a = null;
    return WebGridActionsBaseDirectiveDescriptionMetadata;
})();
